@@ -2,13 +2,22 @@ import asyncio
 import itertools
 
 import time
-from typing import Any, Iterable, Optional, Callable
+from typing import Any, Iterable, Optional, Callable, AsyncIterator,AsyncGenerator
 from aiohttp import ClientSession, TCPConnector, ClientTimeout
 from contextlib import asynccontextmanager
+
 from ..decorators.core import async_retry
 from .interface import RequestResult
 from .progress import ProgressTracker, ProgressBarConfig
 
+from dataclasses import dataclass
+
+
+@dataclass
+class StreamingResult:
+    completed_requests: list[RequestResult]
+    progress: Optional[ProgressTracker]
+    is_final: bool
 
 
 class RateLimiter:
@@ -90,6 +99,7 @@ class ConcurrentRequester:
             request_id: int,
             url: str,
             method: str = 'POST',
+            meta: dict = None,
             **kwargs
     ) -> RequestResult:
         """发送单个请求"""
@@ -117,6 +127,7 @@ class ConcurrentRequester:
                             request_id=request_id,
                             data=error_info,
                             status='error',
+                            meta=meta,
                             latency=latency
                         )
 
@@ -124,6 +135,7 @@ class ConcurrentRequester:
                         request_id=request_id,
                         data=data,
                         status="success",
+                        meta=meta,
                         latency=latency
                     )
 
@@ -132,6 +144,7 @@ class ConcurrentRequester:
                     request_id=request_id,
                     data={'error': 'Timeout error', 'detail': str(e)},
                     status='error',
+                    meta=meta,
                     latency=time.time() - start_time
                 )
             except Exception as e:
@@ -139,9 +152,127 @@ class ConcurrentRequester:
                     request_id=request_id,
                     data={'error': e.__class__.__name__, 'detail': str(e)},
                     status='error',
+                    meta=meta,
                     latency=time.time() - start_time
                 )
 
+    async def process_with_concurrency_window(
+            self,
+            items: Iterable,
+            process_func: Callable,
+            concurrency_limit: int,
+            progress: Optional[ProgressTracker] = None,
+            batch_size: int = 1,
+    ) -> AsyncGenerator[StreamingResult, Any]:
+        """
+        使用滑动窗口方式处理并发任务，支持流式返回结果
+
+        Args:
+            items: 待处理的项目迭代器
+            process_func: 处理单个项目的异步函数，接收item和项目item_id作为参数
+            concurrency_limit: 并发限制数量,也是窗口大小
+            progress: 可选的进度跟踪器
+            batch_size: 每次yield返回的最小完成请求数量
+
+        Yields:
+             生成 StreamingResult 对象序列
+        """
+
+        async def handle_completed_tasks(done_tasks, batch, is_final=False):
+            """内部函数处理已完成的任务"""
+            for task in done_tasks:
+                result = await task
+                if progress:
+                    progress.update(result)
+                batch.append(result)
+
+            if len(batch) >= batch_size or (is_final and batch):
+                if is_final and progress:
+                    progress.print_summary()
+                yield StreamingResult(
+                    completed_requests=sorted(batch, key=lambda x: x.request_id),
+                    progress=progress,
+                    is_final=is_final
+                )
+                batch.clear()
+
+        item_id = 0
+        active_tasks = set()
+        completed_batch = []
+
+        # 处理输入项目
+        for item in items:
+            if len(active_tasks) >= concurrency_limit:
+                done, active_tasks = await asyncio.wait(
+                    active_tasks,
+                    return_when=asyncio.FIRST_COMPLETED
+                )
+                async for result in handle_completed_tasks(done, completed_batch):
+                    yield result
+
+            active_tasks.add(asyncio.create_task(process_func(item, item_id)))
+            item_id += 1
+
+        # 处理剩余任务
+        if active_tasks:
+            done, _ = await asyncio.wait(active_tasks)
+            async for result in handle_completed_tasks(done, completed_batch, is_final=True):
+                yield result
+
+    async def stream_requests(
+            self,
+            request_params: Iterable[dict[str, Any]],
+            url: str,
+            method: str = 'POST',
+            total_requests: Optional[int] = None,
+            show_progress: bool = True,
+            batch_size: int|None = None
+    ) -> AsyncIterator[StreamingResult]:
+        """
+        流式处理批量请求，实时返回已完成的结果
+
+        Args:
+            request_params: 请求参数列表
+            url: 请求URL
+            method: 请求方法
+            total_requests: 总请求数量
+            show_progress: 是否显示进度
+            batch_size: 每次yield返回的最小完成请求数量
+
+        Yields:
+            StreamingResult: 包含已完成的请求结果和进度信息
+        """
+        progress = None
+        if batch_size is None:
+            batch_size = self._concurrency_limit
+        if total_requests is None and show_progress:
+            request_params, params_for_counting = itertools.tee(request_params)
+            total_requests = sum(1 for _ in params_for_counting)
+
+        if show_progress and total_requests is not None:
+            progress = ProgressTracker(
+                total_requests,
+                concurrency=self._concurrency_limit,
+                config=ProgressBarConfig()
+            )
+
+        async with self._get_session() as session:
+            async for result in self.process_with_concurrency_window(
+                    items=request_params,
+                    process_func=lambda params, request_id: self._send_single_request(
+                        session=session,
+                        request_id=request_id,
+                        url=url,
+                        method=method,
+                        meta=params.pop('meta', None),
+                        **params
+                    ),
+                    concurrency_limit=self._concurrency_limit,
+                    progress=progress,
+                    batch_size=batch_size,
+            ):
+                yield result
+
     async def process_requests(
             self,
             request_params: Iterable[dict[str, Any]],
@@ -157,11 +288,8 @@ class ConcurrentRequester:
             Tuple[list[RequestResult], Optional[ProgressTracker]]:
             请求结果列表和进度跟踪器（如果启用了进度显示）
         """
-        # --------------------------------
-        # 如果没有提供total_requests，且需要显示进度，则计算总数
         progress = None
         if total_requests is None and show_progress:
-            # 创建迭代器的副本
             request_params, params_for_counting = itertools.tee(request_params)
             total_requests = sum(1 for _ in params_for_counting)
 
@@ -172,75 +300,22 @@ class ConcurrentRequester:
                 config=ProgressBarConfig()
             )
 
+        results = []
         async with self._get_session() as session:
-            results = await self.process_with_concurrency_window(
+            async for result in self.process_with_concurrency_window(
                 items=request_params,
                 process_func=lambda params, request_id: self._send_single_request(
                     session=session,
                     request_id=request_id,
                     url=url,
                     method=method,
+                    meta=params.pop('meta', None),
                     **params
                 ),
                 concurrency_limit=self._concurrency_limit,
-                progress=progress
-            )
-
-            if progress:
-                progress.print_summary()
-
-            return results, progress
-
-
-    async def process_with_concurrency_window(
-        self,
-        items: Iterable,
-        process_func: Callable,
-        concurrency_limit: int,
-        progress: Optional[ProgressTracker] = None,
-    ) -> list:
-        """
-        使用滑动窗口方式处理并发任务
-
-        Args:
-            items: 待处理的项目迭代器
-            process_func: 处理单个项目的异步函数，接收item和项目item_id作为参数
-            concurrency_limit: 并发限制数量,也是窗口大小
-            progress: 可选的进度跟踪器
-
-        Returns:
-            list[R]: 按照输入顺序返回的处理结果列表
-        """
-        results = []
-        item_id = 0
-        active_tasks = set()
-
-        for item in items:
-            # 如果活跃任务数达到并发限制，等待某个任务完成
-            if len(active_tasks) >= concurrency_limit:
-                done, active_tasks = await asyncio.wait(
-                    active_tasks,
-                    return_when=asyncio.FIRST_COMPLETED
-                )
-                # 处理完成的任务结果
-                for task in done:
-                    result = await task
-                    if progress:
-                        progress.update(result)
-                    results.append(result)
-
-            # 创建新任务
-            task = asyncio.create_task(process_func(item, item_id))
-            active_tasks.add(task)
-            item_id += 1
-
-        # 等待剩余任务完成
-        if active_tasks:
-            done, _ = await asyncio.wait(active_tasks)
-            for task in done:
-                result = await task
-                if progress:
-                    progress.update(result)
-                results.append(result)
-
-        return sorted(results, key=lambda x: getattr(x, 'request_id', 0))
+                progress=progress,
+            ):
+                results.extend(result.completed_requests)
+        # sort
+        results = sorted(results, key=lambda x: x.request_id)
+        return results, progress
